Configured project tools
========================

 * test and deployment via tox tool
 * task management with make
 * setup python environment
 * multi python version testing
 * docs generation with live edit
 * version bump
 * changelog generation
 * local deployment server with pipy substitute